@@ -1295,6 +1295,7 @@ def plot_elution_profile(
     mass_dict: dict,
     colorscale_qualitative: str,
     colorscale_sequential: str,
+    calculate_fragment_masses: bool = True,
     mz_tol: float = 50,
     rt_tol: float = 30,
     im_tol: float = 0.05,
@@ -1302,16 +1303,22 @@ def plot_elution_profile(
     # width: int = 900,
     height: int = 400,
 ):
-    """Plot an elution profile plot for the specified precursor and all his identified fragments.
+    """Plot an elution profile plot for the specified precursor and all
+    his identified fragments.
 
     Parameters
     ----------
     raw_data : alphatims.bruker.TimsTOF
         An alphatims.bruker.TimsTOF data object.
     peptide_info : dict
-        Peptide information including sequence, fragments' patterns, rt, mz and im values.
+        Peptide information including sequence, fragments' patterns, rt, mz
+        and im values.
     mass_dict : dict
-        The basic mass dictionaty with the masses of all amino acids and modifications.
+        The basic mass dictionaty with the masses of all amino acids
+        and modifications.
+    calculate_fragment_masses : bool
+        Whether the fragment masses should be calculated inside the function or
+        they are already provided in the peptide_info dict. Default: True.
     mz_tol: float
         The mz tolerance value. Default: 50 ppm.
     rt_tol: float
@@ -1322,8 +1329,8 @@ def plot_elution_profile(
         The title of the plot.
     # width : int
     #     The width of the plot. Default: 900.
-    # height : int
-    #     The height of the plot. Default: 400.
+    height : int
+        The height of the plot. Default: 400.
 
     Returns
     -------
@@ -1335,14 +1342,15 @@ def plot_elution_profile(
     x_axis_label = "rt"
     y_axis_label = "intensity"
 
-    # predict the theoretical fragments using the Alphapept get_fragmass() function.
-    frag_masses, frag_type = alphaviz.utils.get_fragmass(
-        parsed_pep=alphaviz.utils.parse(peptide_info['sequence']),
-        mass_dict=mass_dict
-    )
-    peptide_info['fragments'] = {
-        (f"b{key}" if key > 0 else f"y{-key}"): value for key, value in zip(frag_type, frag_masses)
-    }
+    if calculate_fragment_masses:
+        # predict the theoretical fragments using the Alphapept get_fragmass() function.
+        frag_masses, frag_type = alphaviz.utils.get_fragmass(
+            parsed_pep=alphaviz.utils.parse(peptide_info['sequence']),
+            mass_dict=mass_dict
+        )
+        peptide_info['fragments'] = {
+            (f"b{key}" if key > 0 else f"y{-key}"): value for key, value in zip(frag_type, frag_masses)
+        }
 
     # slice the data using the rt_tol, im_tol and mz_tol values
     rt_slice = slice(peptide_info['rt'] - rt_tol, peptide_info['rt'] + rt_tol)
